import { CoinFamily } from './base';
export declare enum NetworkType {
    MAINNET = "mainnet",
    TESTNET = "testnet"
}
export declare abstract class BaseNetwork {
    abstract readonly name: string;
    abstract readonly type: NetworkType;
    abstract readonly family: CoinFamily;
    abstract readonly explorerUrl: string | undefined;
}
export interface UtxoNetwork extends BaseNetwork {
    utxolibName: string;
    paygoAddressAttestationPubkey?: string;
}
export interface LightningNetwork extends UtxoNetwork {
    /**
     * The public key of the Lightning service, used for deriving the shared Elliptic Curve Diffie-Hellman (ECDH) secret
     * between the user's extended private key and the Lightning service. This key facilitates secure communication
     * by enabling the creation of a shared secret for encryption and decryption of data.
     */
    lightningServicePubKey: string;
    /**
     * The public key of the middleware service, used for deriving the shared Elliptic Curve Diffie-Hellman (ECDH) secret
     * between the user's extended private key and the middleware service.
     */
    middlewarePubKey: string;
    /**
     * The public key of the TAT service, used for deriving the shared Elliptic Curve Diffie-Hellman (ECDH) secret
     * between the user's extended private key and the TAT service.
     */
    tatPubKey: string;
}
export interface AdaNetwork extends BaseNetwork {
    utxolibName: string;
    poolDeposit: number;
    stakeKeyDeposit: number;
    maxValueSize: number;
    maxTransactionSize: number;
    coinsPerUtxoWord: number;
}
export interface AvalancheNetwork extends BaseNetwork {
    readonly alias: string;
    readonly blockchainID: string;
    readonly cChainBlockchainID: string;
    readonly networkID: number;
    readonly hrp: string;
    readonly vm: string;
    readonly creationTxFee: string;
    readonly createSubnetTx: string;
    readonly createChainTx: string;
    readonly minConsumption: string;
    readonly maxConsumption: string;
    readonly maxSupply: string;
    readonly minStake: string;
    readonly minStakeDuration: string;
    readonly maxStakeDuration: string;
    readonly minDelegationStake: string;
    readonly minDelegationFee: string;
    readonly avaxAssetID: string;
    readonly txFee: string;
    readonly maxImportFee: string;
}
export interface AccountNetwork extends BaseNetwork {
    readonly accountExplorerUrl?: string;
    readonly blockExplorerUrl?: string;
}
/**
 * Specification name type of the chain. Used in setting up the registry
 */
export type PolkadotSpecNameType = 'kusama' | 'polkadot' | 'westend' | 'statemint' | 'statemine';
export type SubstrateSpecNameType = 'kusama' | 'polkadot' | 'westend' | 'statemint' | 'statemine' | 'node-subtensor' | 'polymesh_testnet';
export interface DotNetwork extends AccountNetwork {
    readonly specName: PolkadotSpecNameType;
    readonly genesisHash: string;
    readonly specVersion: number;
    readonly chainName: string;
    readonly txVersion: number;
}
export interface EthereumNetwork extends AccountNetwork {
    readonly chainId: number;
    readonly batcherContractAddress?: string;
    readonly forwarderFactoryAddress?: string;
    readonly forwarderImplementationAddress?: string;
    readonly nativeCoinOperationHashPrefix?: string;
    readonly tokenOperationHashPrefix?: string;
}
export interface TronNetwork extends AccountNetwork {
    maxFeeLimit: string;
    contractCallFeeLimit: string;
}
export interface StacksNetwork extends AccountNetwork {
    readonly sendmanymemoContractAddress: string;
    readonly stakingContractAddress: string;
}
export interface OfcNetwork extends BaseNetwork {
}
declare abstract class Mainnet extends BaseNetwork {
    type: NetworkType;
}
declare abstract class Testnet extends BaseNetwork {
    type: NetworkType;
}
declare class Algorand extends Mainnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
}
declare class AlgorandTestnet extends Testnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
}
declare class Ada extends Mainnet implements AdaNetwork {
    name: string;
    family: CoinFamily;
    utxolibName: string;
    poolDeposit: number;
    stakeKeyDeposit: number;
    explorerUrl: string;
    coinsPerUtxoWord: number;
    maxTransactionSize: number;
    maxValueSize: number;
}
declare class AdaTestnet extends Testnet implements AdaNetwork {
    name: string;
    family: CoinFamily;
    utxolibName: string;
    explorerUrl: string;
    coinsPerUtxoWord: number;
    maxTransactionSize: number;
    maxValueSize: number;
    poolDeposit: number;
    stakeKeyDeposit: number;
}
declare class Apt extends Mainnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    accountExplorerUrl: string;
    blockExplorerUrl: string;
}
declare class AptTestnet extends Testnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    accountExplorerUrl: string;
    blockExplorerUrl: string;
}
declare class Icp extends Mainnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    accountExplorerUrl: string;
}
declare class IcpTestnet extends Testnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    accountExplorerUrl: string;
}
declare class Arbitrum extends Mainnet implements EthereumNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    accountExplorerUrl: string;
    chainId: number;
    nativeCoinOperationHashPrefix: string;
    tokenOperationHashPrefix: string;
    forwarderFactoryAddress: string;
    forwarderImplementationAddress: string;
    walletFactoryAddress: string;
    walletImplementationAddress: string;
    batcherContractAddress: string;
}
declare class ArbitrumTestnet extends Testnet implements EthereumNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    accountExplorerUrl: string;
    chainId: number;
    nativeCoinOperationHashPrefix: string;
    tokenOperationHashPrefix: string;
    forwarderFactoryAddress: string;
    forwarderImplementationAddress: string;
    walletFactoryAddress: string;
    walletImplementationAddress: string;
    batcherContractAddress: string;
}
declare class AvalancheC extends Mainnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    accountExplorerUrl: string;
    chainId: number;
}
declare class AvalancheCTestnet extends Testnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    accountExplorerUrl: string;
    chainId: number;
}
declare class AvalancheP extends Mainnet implements AvalancheNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    accountExplorerUrl: string;
    blockchainID: string;
    cChainBlockchainID: string;
    avaxAssetID: string;
    networkID: number;
    hrp: string;
    alias: string;
    vm: string;
    txFee: string;
    maxImportFee: string;
    createSubnetTx: string;
    createChainTx: string;
    creationTxFee: string;
    minConsumption: string;
    maxConsumption: string;
    maxSupply: string;
    minStake: string;
    minStakeDuration: string;
    maxStakeDuration: string;
    minDelegationStake: string;
    minDelegationFee: string;
}
declare class AvalanchePTestnet extends Testnet implements AvalancheNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    accountExplorerUrl: string;
    blockchainID: string;
    cChainBlockchainID: string;
    avaxAssetID: string;
    networkID: number;
    alias: string;
    hrp: string;
    vm: string;
    txFee: string;
    maxImportFee: string;
    createSubnetTx: string;
    createChainTx: string;
    creationTxFee: string;
    minConsumption: string;
    maxConsumption: string;
    maxSupply: string;
    minStake: string;
    minStakeDuration: string;
    maxStakeDuration: string;
    minDelegationStake: string;
    minDelegationFee: string;
}
declare class BinanceSmartChain extends Mainnet implements EthereumNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    accountExplorerUrl: string;
    chainId: number;
    nativeCoinOperationHashPrefix: string;
    tokenOperationHashPrefix: string;
    batcherContractAddress: string;
}
declare class BinanceSmartChainTestnet extends Testnet implements EthereumNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    accountExplorerUrl: string;
    chainId: number;
    nativeCoinOperationHashPrefix: string;
    tokenOperationHashPrefix: string;
    batcherContractAddress: string;
}
declare class LightningBitcoin extends Mainnet implements LightningNetwork {
    name: string;
    family: CoinFamily;
    utxolibName: string;
    explorerUrl: string;
    lightningServicePubKey: string;
    middlewarePubKey: string;
    tatPubKey: string;
}
declare class LightningBitcoinTestnet extends Testnet implements LightningNetwork {
    name: string;
    family: CoinFamily;
    utxolibName: string;
    explorerUrl: string;
    lightningServicePubKey: string;
    middlewarePubKey: string;
    tatPubKey: string;
}
declare class Bitcoin extends Mainnet implements UtxoNetwork {
    name: string;
    family: CoinFamily;
    utxolibName: string;
    explorerUrl: string;
}
declare class BitcoinTestnet extends Testnet implements UtxoNetwork {
    name: string;
    family: CoinFamily;
    utxolibName: string;
    explorerUrl: string;
    paygoAddressAttestationPubkey: string;
}
declare class BitcoinPublicSignet extends Testnet implements UtxoNetwork {
    name: string;
    family: CoinFamily;
    utxolibName: string;
    explorerUrl: string;
}
declare class BitcoinTestnet4 extends Testnet implements UtxoNetwork {
    name: string;
    family: CoinFamily;
    utxolibName: string;
    explorerUrl: string;
}
declare class BitcoinBitGoSignet extends Testnet implements UtxoNetwork {
    name: string;
    family: CoinFamily;
    utxolibName: string;
    explorerUrl: string;
}
declare class BitcoinCash extends Mainnet implements UtxoNetwork {
    name: string;
    family: CoinFamily;
    utxolibName: string;
    explorerUrl: string;
}
declare class BitcoinCashTestnet extends Testnet implements UtxoNetwork {
    name: string;
    family: CoinFamily;
    utxolibName: string;
    explorerUrl: string;
}
declare class BitcoinSV extends Mainnet implements UtxoNetwork {
    name: string;
    family: CoinFamily;
    utxolibName: string;
    explorerUrl: string;
}
declare class BitcoinSVTestnet extends Testnet implements UtxoNetwork {
    name: string;
    family: CoinFamily;
    utxolibName: string;
    explorerUrl: undefined;
}
declare class BitcoinGold extends Mainnet implements UtxoNetwork {
    name: string;
    family: CoinFamily;
    utxolibName: string;
    explorerUrl: string;
}
declare class BitcoinGoldTestnet extends Testnet implements UtxoNetwork {
    name: string;
    family: CoinFamily;
    utxolibName: string;
    explorerUrl: undefined;
}
declare class Dash extends Mainnet implements UtxoNetwork {
    name: string;
    family: CoinFamily;
    utxolibName: string;
    explorerUrl: string;
}
declare class DashTestnet extends Testnet implements UtxoNetwork {
    name: string;
    family: CoinFamily;
    utxolibName: string;
    explorerUrl: string;
}
declare class Dogecoin extends Mainnet implements UtxoNetwork {
    name: string;
    family: CoinFamily;
    utxolibName: string;
    explorerUrl: string;
}
declare class DogecoinTestnet extends Testnet implements UtxoNetwork {
    name: string;
    family: CoinFamily;
    utxolibName: string;
    explorerUrl: string;
}
declare class ECash extends Mainnet implements UtxoNetwork {
    name: string;
    family: CoinFamily;
    utxolibName: string;
    explorerUrl: string;
}
declare class ECashTestnet extends Testnet implements UtxoNetwork {
    name: string;
    family: CoinFamily;
    utxolibName: string;
    explorerUrl: undefined;
}
declare class Polkadot extends Mainnet implements DotNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    specName: PolkadotSpecNameType;
    genesisHash: string;
    specVersion: number;
    chainName: string;
    txVersion: number;
}
declare class PolkadotTestnet extends Testnet implements DotNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    specName: PolkadotSpecNameType;
    genesisHash: string;
    specVersion: number;
    chainName: string;
    txVersion: number;
}
declare class Celo extends Mainnet implements EthereumNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    accountExplorerUrl: string;
    chainId: number;
    nativeCoinOperationHashPrefix: string;
    tokenOperationHashPrefix: string;
}
declare class CeloTestnet extends Testnet implements EthereumNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    accountExplorerUrl: string;
    chainId: number;
    nativeCoinOperationHashPrefix: string;
    tokenOperationHashPrefix: string;
}
declare class Casper extends Mainnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    accountExplorerUrl: string;
}
declare class CasperTestnet extends Testnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    accountExplorerUrl: string;
}
declare class Ethereum extends Mainnet implements EthereumNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    accountExplorerUrl: string;
    blockExplorerUrl: string;
    chainId: number;
    batcherContractAddress: string;
    forwarderFactoryAddress: string;
    forwarderImplementationAddress: string;
    nativeCoinOperationHashPrefix: string;
    tokenOperationHashPrefix: string;
}
declare class Ethereum2 extends Mainnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    accountExplorerUrl: string;
}
declare class EthereumW extends Mainnet implements EthereumNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    accountExplorerUrl: string;
    chainId: number;
    batcherContractAddress: string;
    forwarderFactoryAddress: string;
    forwarderImplementationAddress: string;
    nativeCoinOperationHashPrefix: string;
    tokenOperationHashPrefix: string;
}
declare class Pyrmont extends Testnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    accountExplorerUrl: string;
}
declare class Kovan extends Testnet implements EthereumNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    accountExplorerUrl: string;
    chainId: number;
    batcherContractAddress: string;
    forwarderFactoryAddress: string;
    forwarderImplementationAddress: string;
    nativeCoinOperationHashPrefix: string;
    tokenOperationHashPrefix: string;
}
declare class Goerli extends Testnet implements EthereumNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    accountExplorerUrl: string;
    blockExplorerUrl: string;
    chainId: number;
    batcherContractAddress: string;
    forwarderFactoryAddress: string;
    forwarderImplementationAddress: string;
    nativeCoinOperationHashPrefix: string;
    tokenOperationHashPrefix: string;
}
declare class Holesky extends Testnet implements EthereumNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    accountExplorerUrl: string;
    blockExplorerUrl: string;
    chainId: number;
    batcherContractAddress: string;
    forwarderFactoryAddress: string;
    forwarderImplementationAddress: string;
    nativeCoinOperationHashPrefix: string;
    tokenOperationHashPrefix: string;
}
declare class EthereumClassic extends Mainnet implements EthereumNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    accountExplorerUrl: string;
    chainId: number;
    nativeCoinOperationHashPrefix: string;
    tokenOperationHashPrefix: string;
}
declare class EthereumClassicTestnet extends Testnet implements EthereumNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    accountExplorerUrl: string;
    chainId: number;
    nativeCoinOperationHashPrefix: string;
    tokenOperationHashPrefix: string;
}
declare class Eos extends Mainnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
}
declare class EosTestnet extends Testnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
}
declare class Hedera extends Mainnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
}
declare class HederaTestnet extends Testnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
}
declare class Litecoin extends Mainnet implements UtxoNetwork {
    name: string;
    family: CoinFamily;
    utxolibName: string;
    explorerUrl: string;
}
declare class LitecoinTestnet extends Testnet implements UtxoNetwork {
    name: string;
    family: CoinFamily;
    utxolibName: string;
    explorerUrl: string;
}
declare class Ofc extends Mainnet implements OfcNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: undefined;
}
declare class OfcTestnet extends Testnet implements OfcNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: undefined;
}
declare class Rbtc extends Mainnet implements EthereumNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    accountExplorerUrl: string;
    chainId: number;
    nativeCoinOperationHashPrefix: string;
    tokenOperationHashPrefix: string;
}
declare class RbtcTestnet extends Testnet implements EthereumNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    accountExplorerUrl: string;
    chainId: number;
    nativeCoinOperationHashPrefix: string;
    tokenOperationHashPrefix: string;
}
declare class Stellar extends Mainnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
}
declare class StellarTestnet extends Testnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
}
declare class Sol extends Mainnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
}
declare class SolTestnet extends Testnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
}
declare class Sui extends Mainnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
}
declare class SuiTestnet extends Testnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
}
declare class Atom extends Mainnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
}
declare class AtomTestnet extends Testnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
}
declare class Osmo extends Mainnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
}
declare class OsmoTestnet extends Testnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
}
declare class Tia extends Mainnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
}
declare class TiaTestnet extends Testnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
}
declare class Hash extends Mainnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
}
declare class HashTestnet extends Testnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
}
declare class Bld extends Mainnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
}
declare class BldTestnet extends Testnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
}
declare class Sei extends Mainnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
}
declare class SeiTestnet extends Testnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
}
declare class Zeta extends Mainnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
}
declare class ZetaTestnet extends Testnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
}
declare class Injective extends Mainnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
}
declare class InjectiveTestnet extends Testnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
}
declare class Kava extends Mainnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
}
declare class KavaTestnet extends Testnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
}
declare class Ton extends Mainnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
}
declare class TonTestnet extends Testnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
}
declare class Coreum extends Mainnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
}
declare class CoreumTestnet extends Testnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
}
declare class Rune extends Mainnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
}
declare class RuneTestNet extends Testnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
}
declare class Baby extends Mainnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
}
declare class BabyTestnet extends Testnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
}
declare class Mantra extends Mainnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
}
declare class MantraTestnet extends Testnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
}
declare class Cronos extends Mainnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
}
declare class CronosTestnet extends Testnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
}
declare class FetchAi extends Mainnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
}
declare class FetchAiTestnet extends Testnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
}
declare class Initia extends Mainnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
}
declare class InitiaTestnet extends Testnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
}
declare class Asi extends Mainnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
}
declare class AsiTestnet extends Testnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
}
declare class Islm extends Mainnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
}
declare class IslmTestnet extends Testnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
}
declare class Stx extends Mainnet implements StacksNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    sendmanymemoContractAddress: string;
    stakingContractAddress: string;
}
declare class StxTestnet extends Testnet implements StacksNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    sendmanymemoContractAddress: string;
    stakingContractAddress: string;
}
declare class SUSD extends Mainnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: undefined;
}
declare class SUSDTestnet extends Testnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: undefined;
}
declare class FiatTestnet extends Testnet implements BaseNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: undefined;
}
declare class Fiat extends Mainnet implements BaseNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: undefined;
}
declare class Bittensor extends Mainnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
}
declare class BittensorTestnet extends Testnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    specName: SubstrateSpecNameType;
    genesisHash: string;
    specVersion: number;
    chainName: string;
    txVersion: number;
}
declare class Trx extends Mainnet implements TronNetwork {
    name: string;
    family: CoinFamily;
    accountExplorerUrl: string;
    explorerUrl: string;
    maxFeeLimit: string;
    contractCallFeeLimit: string;
}
declare class TrxTestnet extends Testnet implements TronNetwork {
    name: string;
    family: CoinFamily;
    accountExplorerUrl: string;
    explorerUrl: string;
    maxFeeLimit: string;
    contractCallFeeLimit: string;
}
declare class Xrp extends Mainnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
}
declare class XrpTestnet extends Testnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
}
declare class Xtz extends Mainnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    accountExplorerUrl: string;
}
declare class XtzTestnet extends Testnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    accountExplorerUrl: string;
}
declare class ZCash extends Mainnet implements UtxoNetwork {
    name: string;
    family: CoinFamily;
    utxolibName: string;
    explorerUrl: string;
}
declare class ZCashTestnet extends Testnet implements UtxoNetwork {
    name: string;
    family: CoinFamily;
    utxolibName: string;
    explorerUrl: string;
}
declare class Near extends Mainnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    feeReserve: string;
    storageReserve: string;
}
declare class NearTestnet extends Testnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    feeReserve: string;
    storageReserve: string;
}
declare class Polygon extends Mainnet implements EthereumNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    accountExplorerUrl: string;
    chainId: number;
    forwarderFactoryAddress: string;
    forwarderImplementationAddress: string;
    walletFactoryAddress: string;
    walletImplementationAddress: string;
    batcherContractAddress: string;
    nativeCoinOperationHashPrefix: string;
    tokenOperationHashPrefix: string;
}
declare class PolygonTestnet extends Testnet implements EthereumNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    accountExplorerUrl: string;
    chainId: number;
    forwarderFactoryAddress: string;
    forwarderImplementationAddress: string;
    walletFactoryAddress: string;
    walletImplementationAddress: string;
    batcherContractAddress: string;
    nativeCoinOperationHashPrefix: string;
    tokenOperationHashPrefix: string;
}
declare class Optimism extends Mainnet implements EthereumNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    accountExplorerUrl: string;
    chainId: number;
    nativeCoinOperationHashPrefix: string;
    tokenOperationHashPrefix: string;
    forwarderFactoryAddress: string;
    forwarderImplementationAddress: string;
    walletFactoryAddress: string;
    walletImplementationAddress: string;
    batcherContractAddress: string;
}
declare class OptimismTestnet extends Testnet implements EthereumNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    accountExplorerUrl: string;
    chainId: number;
    nativeCoinOperationHashPrefix: string;
    tokenOperationHashPrefix: string;
    forwarderFactoryAddress: string;
    forwarderImplementationAddress: string;
    walletFactoryAddress: string;
    walletImplementationAddress: string;
    batcherContractAddress: string;
}
declare class ZkSync extends Mainnet implements EthereumNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    accountExplorerUrl: string;
    chainId: number;
    nativeCoinOperationHashPrefix: string;
    tokenOperationHashPrefix: string;
}
declare class ZkSyncTestnet extends Testnet implements EthereumNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    accountExplorerUrl: string;
    chainId: number;
    nativeCoinOperationHashPrefix: string;
    tokenOperationHashPrefix: string;
    forwarderFactoryAddress: string;
    forwarderImplementationAddress: string;
    walletFactoryAddress: string;
    walletImplementationAddress: string;
}
declare class Berachain extends Mainnet implements EthereumNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    accountExplorerUrl: string;
    chainId: number;
    nativeCoinOperationHashPrefix: string;
    tokenOperationHashPrefix: string;
    batcherContractAddress: string;
    forwarderFactoryAddress: string;
    forwarderImplementationAddress: string;
}
declare class BerachainTestnet extends Testnet implements EthereumNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    accountExplorerUrl: string;
    chainId: number;
    nativeCoinOperationHashPrefix: string;
    tokenOperationHashPrefix: string;
    batcherContractAddress: string;
    forwarderFactoryAddress: string;
    forwarderImplementationAddress: string;
}
declare class Oas extends Mainnet implements EthereumNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    accountExplorerUrl: string;
    chainId: number;
    nativeCoinOperationHashPrefix: string;
    batcherContractAddress: string;
    forwarderFactoryAddress: string;
    forwarderImplementationAddress: string;
}
declare class OasTestnet extends Testnet implements EthereumNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    accountExplorerUrl: string;
    chainId: number;
    nativeCoinOperationHashPrefix: string;
    batcherContractAddress: string;
    forwarderFactoryAddress: string;
    forwarderImplementationAddress: string;
}
declare class Coredao extends Mainnet implements EthereumNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    accountExplorerUrl: string;
    chainId: number;
    nativeCoinOperationHashPrefix: string;
    batcherContractAddress: string;
    forwarderFactoryAddress: string;
    forwarderImplementationAddress: string;
}
declare class CoredaoTestnet extends Testnet implements EthereumNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    accountExplorerUrl: string;
    chainId: number;
    nativeCoinOperationHashPrefix: string;
    batcherContractAddress: string;
    forwarderFactoryAddress: string;
    forwarderImplementationAddress: string;
}
declare class ApeChain extends Mainnet implements EthereumNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    accountExplorerUrl: string;
    chainId: number;
    nativeCoinOperationHashPrefix: string;
}
declare class ApeChainTestnet extends Testnet implements EthereumNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    accountExplorerUrl: string;
    chainId: number;
    nativeCoinOperationHashPrefix: string;
}
declare class Xdc extends Mainnet implements EthereumNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    accountExplorerUrl: string;
    chainId: number;
    nativeCoinOperationHashPrefix: string;
    batcherContractAddress: string;
    forwarderFactoryAddress: string;
    forwarderImplementationAddress: string;
}
declare class XdcTestnet extends Testnet implements EthereumNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    accountExplorerUrl: string;
    chainId: number;
    nativeCoinOperationHashPrefix: string;
    batcherContractAddress: string;
    forwarderFactoryAddress: string;
    forwarderImplementationAddress: string;
}
declare class Wemix extends Mainnet implements EthereumNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    accountExplorerUrl: string;
    chainId: number;
    nativeCoinOperationHashPrefix: string;
    batcherContractAddress: string;
    forwarderFactoryAddress: string;
    forwarderImplementationAddress: string;
}
declare class WemixTestnet extends Testnet implements EthereumNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    accountExplorerUrl: string;
    chainId: number;
    nativeCoinOperationHashPrefix: string;
    batcherContractAddress: string;
    forwarderFactoryAddress: string;
    forwarderImplementationAddress: string;
}
declare class MonadTestnet extends Testnet implements EthereumNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    accountExplorerUrl: string;
    chainId: number;
    nativeCoinOperationHashPrefix: string;
    walletFactoryAddress: string;
    batcherContractAddress: string;
    forwarderFactoryAddress: string;
    forwarderImplementationAddress: string;
    walletImplementationAddress: string;
}
declare class Monad extends Mainnet implements EthereumNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    chainId: number;
    nativeCoinOperationHashPrefix: string;
    walletImplementationAddress: string;
    batcherContractAddress: string;
    forwarderFactoryAddress: string;
    forwarderImplementationAddress: string;
}
declare class World extends Mainnet implements EthereumNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    accountExplorerUrl: string;
    chainId: number;
    nativeCoinOperationHashPrefix: string;
    walletImplementationAddress: string;
    batcherContractAddress: string;
    forwarderFactoryAddress: string;
    forwarderImplementationAddress: string;
}
declare class WorldTestnet extends Testnet implements EthereumNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    accountExplorerUrl: string;
    chainId: number;
    nativeCoinOperationHashPrefix: string;
    batcherContractAddress: string;
    forwarderFactoryAddress: string;
    forwarderImplementationAddress: string;
    walletImplementationAddress: string;
}
declare class Soneium extends Mainnet implements EthereumNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    accountExplorerUrl: string;
    chainId: number;
    nativeCoinOperationHashPrefix: string;
    walletImplementationAddress: string;
    walletFactoryAddress: string;
    batcherContractAddress: string;
    forwarderFactoryAddress: string;
    forwarderImplementationAddress: string;
}
declare class SoneiumTestnet extends Testnet implements EthereumNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    accountExplorerUrl: string;
    chainId: number;
    nativeCoinOperationHashPrefix: string;
    walletFactoryAddress: string;
    batcherContractAddress: string;
    forwarderFactoryAddress: string;
    forwarderImplementationAddress: string;
    walletImplementationAddress: string;
}
declare class Somnia extends Mainnet implements EthereumNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    chainId: number;
    nativeCoinOperationHashPrefix: string;
}
declare class SomniaTestnet extends Testnet implements EthereumNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    accountExplorerUrl: string;
    chainId: number;
    nativeCoinOperationHashPrefix: string;
    walletFactoryAddress: string;
    batcherContractAddress: string;
    forwarderFactoryAddress: string;
    forwarderImplementationAddress: string;
    walletImplementationAddress: string;
}
declare class Flare extends Mainnet implements EthereumNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    accountExplorerUrl: string;
    chainId: number;
    nativeCoinOperationHashPrefix: string;
    batcherContractAddress: string;
    forwarderFactoryAddress: string;
    forwarderImplementationAddress: string;
}
declare class FlareTestnet extends Testnet implements EthereumNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    accountExplorerUrl: string;
    chainId: number;
    nativeCoinOperationHashPrefix: string;
    batcherContractAddress: string;
    forwarderFactoryAddress: string;
    forwarderImplementationAddress: string;
}
declare class Songbird extends Mainnet implements EthereumNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    accountExplorerUrl: string;
    chainId: number;
    nativeCoinOperationHashPrefix: string;
    batcherContractAddress: string;
    forwarderFactoryAddress: string;
    forwarderImplementationAddress: string;
}
declare class SongbirdTestnet extends Testnet implements EthereumNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    accountExplorerUrl: string;
    chainId: number;
    nativeCoinOperationHashPrefix: string;
    batcherContractAddress: string;
    forwarderFactoryAddress: string;
    forwarderImplementationAddress: string;
}
declare class BaseChainTestnet extends Testnet implements EthereumNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    accountExplorerUrl: string;
    chainId: number;
    nativeCoinOperationHashPrefix: string;
    tokenOperationHashPrefix: string;
    forwarderFactoryAddress: string;
    forwarderImplementationAddress: string;
    walletFactoryAddress: string;
    walletImplementationAddress: string;
}
declare class BaseChain extends Mainnet implements EthereumNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    accountExplorerUrl: string;
    chainId: number;
    nativeCoinOperationHashPrefix: string;
    tokenOperationHashPrefix: string;
    forwarderFactoryAddress: string;
    forwarderImplementationAddress: string;
    walletFactoryAddress: string;
    walletImplementationAddress: string;
}
declare class Polymesh extends Mainnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
}
declare class PolymeshTestnet extends Testnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    specName: SubstrateSpecNameType;
    genesisHash: string;
    specVersion: number;
    chainName: string;
    txVersion: number;
}
declare class Vet extends Mainnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    accountExplorerUrl: string;
}
declare class VetTestnet extends Testnet implements AccountNetwork {
    name: string;
    family: CoinFamily;
    explorerUrl: string;
    accountExplorerUrl: string;
}
export declare const Networks: {
    main: {
        ada: Readonly<Ada>;
        algorand: Readonly<Algorand>;
        apechain: Readonly<ApeChain>;
        apt: Readonly<Apt>;
        arbitrum: Readonly<Arbitrum>;
        asi: Readonly<Asi>;
        atom: Readonly<Atom>;
        avalancheC: Readonly<AvalancheC>;
        avalancheP: Readonly<AvalancheP>;
        baby: Readonly<Baby>;
        basechain: Readonly<BaseChain>;
        bitcoin: Readonly<Bitcoin>;
        bitcoinCash: Readonly<BitcoinCash>;
        bitcoinGold: Readonly<BitcoinGold>;
        bitcoinSV: Readonly<BitcoinSV>;
        bera: Readonly<Berachain>;
        bld: Readonly<Bld>;
        bsc: Readonly<BinanceSmartChain>;
        casper: Readonly<Casper>;
        celo: Readonly<Celo>;
        coredao: Readonly<Coredao>;
        coreum: Readonly<Coreum>;
        cronos: Readonly<Cronos>;
        dash: Readonly<Dash>;
        dogecoin: Readonly<Dogecoin>;
        dot: Readonly<Polkadot>;
        eCash: Readonly<ECash>;
        eos: Readonly<Eos>;
        ethereum: Readonly<Ethereum>;
        ethereum2: Readonly<Ethereum2>;
        ethereumClassic: Readonly<EthereumClassic>;
        ethereumW: Readonly<EthereumW>;
        fiat: Readonly<Fiat>;
        fetchai: Readonly<FetchAi>;
        flr: Readonly<Flare>;
        hash: Readonly<Hash>;
        hedera: Readonly<Hedera>;
        icp: Readonly<Icp>;
        initia: Readonly<Initia>;
        injective: Readonly<Injective>;
        islm: Readonly<Islm>;
        kava: Readonly<Kava>;
        lnbtc: Readonly<LightningBitcoin>;
        litecoin: Readonly<Litecoin>;
        mon: Readonly<Monad>;
        mantra: Readonly<Mantra>;
        polygon: Readonly<Polygon>;
        polyx: Readonly<Polymesh>;
        oas: Readonly<Oas>;
        ofc: Readonly<Ofc>;
        optimism: Readonly<Optimism>;
        osmo: Readonly<Osmo>;
        rbtc: Readonly<Rbtc>;
        rune: Readonly<Rune>;
        stellar: Readonly<Stellar>;
        sei: Readonly<Sei>;
        sgb: Readonly<Songbird>;
        sol: Readonly<Sol>;
        sui: Readonly<Sui>;
        near: Readonly<Near>;
        stx: Readonly<Stx>;
        stt: Readonly<Somnia>;
        soneium: Readonly<Soneium>;
        susd: Readonly<SUSD>;
        tao: Readonly<Bittensor>;
        tia: Readonly<Tia>;
        ton: Readonly<Ton>;
        trx: Readonly<Trx>;
        vet: Readonly<Vet>;
        wemix: Readonly<Wemix>;
        world: Readonly<World>;
        xdc: Readonly<Xdc>;
        xrp: Readonly<Xrp>;
        xtz: Readonly<Xtz>;
        zCash: Readonly<ZCash>;
        zeta: Readonly<Zeta>;
        zkSync: Readonly<ZkSync>;
    };
    test: {
        ada: Readonly<AdaTestnet>;
        algorand: Readonly<AlgorandTestnet>;
        apechain: Readonly<ApeChainTestnet>;
        apt: Readonly<AptTestnet>;
        arbitrum: Readonly<ArbitrumTestnet>;
        asi: Readonly<AsiTestnet>;
        atom: Readonly<AtomTestnet>;
        avalancheC: Readonly<AvalancheCTestnet>;
        avalancheP: Readonly<AvalanchePTestnet>;
        baby: Readonly<BabyTestnet>;
        basechain: Readonly<BaseChainTestnet>;
        bitcoin: Readonly<BitcoinTestnet>;
        bitcoinPublicSignet: Readonly<BitcoinPublicSignet>;
        bitcoinTestnet4: Readonly<BitcoinTestnet4>;
        bitcoinBitGoSignet: Readonly<BitcoinBitGoSignet>;
        bitcoinCash: Readonly<BitcoinCashTestnet>;
        bitcoinGold: Readonly<BitcoinGoldTestnet>;
        bitcoinSV: Readonly<BitcoinSVTestnet>;
        bera: Readonly<BerachainTestnet>;
        bld: Readonly<BldTestnet>;
        bsc: Readonly<BinanceSmartChainTestnet>;
        casper: Readonly<CasperTestnet>;
        coredao: Readonly<CoredaoTestnet>;
        celo: Readonly<CeloTestnet>;
        cronos: Readonly<CronosTestnet>;
        dash: Readonly<DashTestnet>;
        dogecoin: Readonly<DogecoinTestnet>;
        dot: Readonly<PolkadotTestnet>;
        eCash: Readonly<ECashTestnet>;
        eos: Readonly<EosTestnet>;
        fiat: Readonly<FiatTestnet>;
        fetchai: Readonly<FetchAiTestnet>;
        flr: Readonly<FlareTestnet>;
        mon: Readonly<MonadTestnet>;
        pyrmont: Readonly<Pyrmont>;
        ethereumClassicTestnet: Readonly<EthereumClassicTestnet>;
        hash: Readonly<HashTestnet>;
        hedera: Readonly<HederaTestnet>;
        icp: Readonly<IcpTestnet>;
        initia: Readonly<InitiaTestnet>;
        injective: Readonly<InjectiveTestnet>;
        islm: Readonly<IslmTestnet>;
        kava: Readonly<KavaTestnet>;
        kovan: Readonly<Kovan>;
        goerli: Readonly<Goerli>;
        holesky: Readonly<Holesky>;
        lnbtc: Readonly<LightningBitcoinTestnet>;
        litecoin: Readonly<LitecoinTestnet>;
        mantra: Readonly<MantraTestnet>;
        polygon: Readonly<PolygonTestnet>;
        polyx: Readonly<PolymeshTestnet>;
        oas: Readonly<OasTestnet>;
        ofc: Readonly<OfcTestnet>;
        optimism: Readonly<OptimismTestnet>;
        osmo: Readonly<OsmoTestnet>;
        rbtc: Readonly<RbtcTestnet>;
        rune: Readonly<RuneTestNet>;
        sgb: Readonly<SongbirdTestnet>;
        stellar: Readonly<StellarTestnet>;
        sei: Readonly<SeiTestnet>;
        sol: Readonly<SolTestnet>;
        sui: Readonly<SuiTestnet>;
        near: Readonly<NearTestnet>;
        stx: Readonly<StxTestnet>;
        stt: Readonly<SomniaTestnet>;
        soneium: Readonly<SoneiumTestnet>;
        susd: Readonly<SUSDTestnet>;
        coreum: Readonly<CoreumTestnet>;
        tao: Readonly<BittensorTestnet>;
        tia: Readonly<TiaTestnet>;
        ton: Readonly<TonTestnet>;
        trx: Readonly<TrxTestnet>;
        vet: Readonly<VetTestnet>;
        wemix: Readonly<WemixTestnet>;
        world: Readonly<WorldTestnet>;
        xdc: Readonly<XdcTestnet>;
        xrp: Readonly<XrpTestnet>;
        xtz: Readonly<XtzTestnet>;
        zCash: Readonly<ZCashTestnet>;
        zeta: Readonly<ZetaTestnet>;
        zkSync: Readonly<ZkSyncTestnet>;
    };
};
export {};
//# sourceMappingURL=networks.d.ts.map